@@ -281,6 +281,8 @@ public slots:
     void connectionActivated();
     void connectionDeactivated();
     void connectionClosed();
+    void loginSuccess();
+    void loginFailed();
     void read();
     void keepAlive();
     void queueMessage(FMessage message);
@@ -291,6 +293,7 @@ public slots:
     void requestLeaveGroup(QString jid);
     void requestQueryLastOnline(QString jid);
     void userStatusUpdated(FMessage message);
+    void getMyStatus();
     void changeStatus(QString newStatus);
     void changeUserName(QString newUserName);
     void synchronizeContacts();
